@@ -1,12 +1,14 @@
 import logging
+
 import numpy as np
-from sklearn.pipeline import Pipeline
 from sklearn.model_selection import GridSearchCV
+from sklearn.pipeline import Pipeline
+
+from hcrystalball.compose import TSColumnTransformer
+from hcrystalball.feature_extraction import HolidayTransformer
+from hcrystalball.metrics import get_scorer
 
 from ._split import FinerTimeSplit
-from hcrystalball.compose import TSColumnTransformer
-from hcrystalball.metrics import get_scorer
-from hcrystalball.feature_extraction import HolidayTransformer
 
 logger = logging.getLogger(__name__)
 
@@ -39,6 +41,7 @@ def get_gridsearch(
     clip_predictions_lower=None,
     clip_predictions_upper=None,
     exog_cols=None,
+    hcb_verbose=False,
 ):
     """Get grid search object based on selection criteria.
 
@@ -122,6 +125,10 @@ def get_gridsearch(
     exog_cols : list
         List of columns to be used as exogenous variables
 
+    hcb_verbose : bool
+        Whtether to keep (True) or suppress (False) messages to stdout and stderr from the wrapper
+        and 3rd party libraries during fit and predict
+
     Returns
     -------
     sklearn.model_selection.GridSearchCV
@@ -214,25 +221,28 @@ def get_gridsearch(
                     autoarima_dict=autoarima_dict,
                     clip_predictions_lower=clip_predictions_lower,
                     clip_predictions_upper=clip_predictions_upper,
+                    hcb_verbose=hcb_verbose,
                 ),
             )
         )
 
     if stacking_ensembles or average_ensembles or sklearn_models:
-        from sklearn.linear_model import ElasticNet
         from sklearn.ensemble import RandomForestRegressor
+        from sklearn.linear_model import ElasticNet
+
+        from hcrystalball.feature_extraction import SeasonalityTransformer
 
         # TODO when scoring time is fixed, add HistGradientBoostingRegressor
         # from sklearn.experimental import enable_hist_gradient_boosting
         # from sklearn.ensemble import HistGradientBoostingRegressor
         from hcrystalball.wrappers import get_sklearn_wrapper
-        from hcrystalball.feature_extraction import SeasonalityTransformer
 
         sklearn_model = get_sklearn_wrapper(
             RandomForestRegressor,
             random_state=RANDOM_STATE,
             clip_predictions_lower=clip_predictions_lower,
             clip_predictions_upper=clip_predictions_upper,
+            hcb_verbose=hcb_verbose,
         )
 
         sklearn_model_pipeline = Pipeline(
@@ -247,6 +257,7 @@ def get_gridsearch(
                 ElasticNet,
                 clip_predictions_lower=clip_predictions_lower,
                 clip_predictions_upper=clip_predictions_upper,
+                hcb_verbose=hcb_verbose,
             ),
             "RandomForestRegressor": sklearn_model,
         }
@@ -286,6 +297,7 @@ def get_gridsearch(
                     ProphetWrapper(
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ],
                 "model__seasonality_mode": ["multiplicative", "additive"],
@@ -299,6 +311,7 @@ def get_gridsearch(
                     ProphetWrapper(
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ],
                 "model__extra_seasonalities": [
@@ -329,17 +342,14 @@ def get_gridsearch(
                         freq=frequency,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ],
                 "model__trend": ["add"],
                 "model__seasonal": [None, "add"],
                 "model__damped_trend": [True, False],
-                "model__fit_params": [
-                    {"use_boxcox": True, "use_basinhopping": False},
-                    # {'use_boxcox':True, 'use_basinhopping':True},
-                    {"use_boxcox": False, "use_basinhopping": False},
-                    # {'use_boxcox':False, 'use_basinhopping':True}
-                ],
+                "model__use_boxcox": [True, False],
+                "model__use_basinhopping": [False],
             }
         )
 
@@ -350,15 +360,14 @@ def get_gridsearch(
                         freq=frequency,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ],
                 "model__trend": ["add"],
                 "model__seasonal": ["mul"],
                 "model__damped_trend": [True, False],
-                "model__fit_params": [
-                    {"use_boxcox": False, "use_basinhopping": False},
-                    # {'use_boxcox':False, 'use_basinhopping':True}
-                ],
+                "model__use_boxcox": [False],
+                "model__use_basinhopping": [False],
             }
         )
 
@@ -369,15 +378,14 @@ def get_gridsearch(
                         freq=frequency,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ],
                 "model__trend": [None],
                 "model__seasonal": [None, "add", "mul"],
                 "model__damped_trend": [False],
-                "model__fit_params": [
-                    {"use_boxcox": False, "use_basinhopping": False},
-                    # {'use_boxcox':False, 'use_basinhopping':True}
-                ],
+                "model__use_boxcox": [False],
+                "model__use_basinhopping": [False],
             }
         )
 
@@ -387,10 +395,12 @@ def get_gridsearch(
                     SimpleSmoothingWrapper(
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     ),
                     HoltSmoothingWrapper(
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     ),
                 ]
             }
@@ -405,6 +415,7 @@ def get_gridsearch(
                     ThetaWrapper(
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ]
             }
@@ -420,16 +431,18 @@ def get_gridsearch(
                         use_arma_errors=False,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
+                        hcb_verbose=hcb_verbose,
                     )
                 ]
             }
         )
 
     if stacking_ensembles:
+        from sklearn.ensemble import RandomForestRegressor
+
         from hcrystalball.ensemble import StackingEnsemble
         from hcrystalball.wrappers import ProphetWrapper
         from hcrystalball.wrappers import ThetaWrapper
-        from sklearn.ensemble import RandomForestRegressor
 
         grid_search.param_grid.append(
             {
@@ -451,11 +464,13 @@ def get_gridsearch(
                         ProphetWrapper(
                             clip_predictions_lower=clip_predictions_lower,
                             clip_predictions_upper=clip_predictions_upper,
+                            hcb_verbose=hcb_verbose,
                         ),
                         sklearn_model_pipeline,
                         ThetaWrapper(
                             clip_predictions_lower=clip_predictions_lower,
                             clip_predictions_upper=clip_predictions_upper,
+                            hcb_verbose=hcb_verbose,
                         ),
                     ],
                 ],
@@ -480,11 +495,13 @@ def get_gridsearch(
                         ProphetWrapper(
                             clip_predictions_lower=clip_predictions_lower,
                             clip_predictions_upper=clip_predictions_upper,
+                            hcb_verbose=hcb_verbose,
                         ),
                         sklearn_model_pipeline,
                         ThetaWrapper(
                             clip_predictions_lower=clip_predictions_lower,
                             clip_predictions_upper=clip_predictions_upper,
+                            hcb_verbose=hcb_verbose,
                         ),
                     ],
                 ],
