@@ -1,18 +1,19 @@
-import itertools
-from copy import deepcopy
-import pandas as pd
-import sys
 import io
-from collections import OrderedDict
-
-from ._data_preparation import partition_data
-from ._data_preparation import filter_data
-from ._data_preparation import prepare_data_for_training
-from ._model_selector_result import ModelSelectorResult
-from .utils import persist_experts_in_physical_partition
+import itertools
 
 # redirect prefect to the console
 import logging
+import sys
+from collections import OrderedDict
+from copy import deepcopy
+
+import pandas as pd
+
+from ._data_preparation import filter_data
+from ._data_preparation import partition_data
+from ._data_preparation import prepare_data_for_training
+from ._model_selector_result import ModelSelectorResult
+from .utils import persist_experts_in_physical_partition
 
 logger = logging.getLogger(__name__)
 
@@ -43,6 +44,49 @@ def make_progress_bar(*args, **kwargs):
     return pbar
 
 
+def get_best_not_failing_model(grid_search, X, y):
+    """
+    Prevent situation when model incompatible data are not seen during CV (in the last split of actuals) and
+    model which cannot be fitted on the full dataset is choseen. In such a situation the next model with the
+    lowest test score should be selected.
+
+    Parameters
+    ----------
+    grid_search : sklearn.model_selection.GridSearchCV
+        Fitted instance compatible with Sklearn GridSearchCV
+
+    X : pandas.DataFrame
+            Input features.
+
+    y : array_like, (1d)
+            Target vector.
+
+    Returns
+    -------
+    dict
+        with keys `rank` and `params`
+
+    Raises
+    ------
+    ValueError
+        No available model could be fit on given data
+    """
+    params_ranks = (
+        pd.DataFrame(grid_search.cv_results_)[["rank_test_score", "params"]]
+        .sort_values("rank_test_score")
+        .to_dict("records")
+    )
+
+    for param_rank in params_ranks:
+        try:
+            grid_search.estimator.set_params(**param_rank["params"]).fit(X, y)
+            return {"rank": param_rank["rank_test_score"], "params": param_rank["params"]}
+        except Exception:
+            continue
+
+    raise ValueError("No available model could be fit on given data")
+
+
 def select_model(
     df,
     target_col_name,
@@ -121,12 +165,14 @@ def select_model(
 
         # searches among all models with found best Sarimax on last split (as opose to using AutoSarimax)
         grid_search_tmp.fit(X, y)
+        best_param_rank = get_best_not_failing_model(grid_search_tmp, X, y)
         # add convenient result object
         results.append(
             ModelSelectorResult(
                 # more robust refit=True that makes sure, that models failing during fit
                 # are ommited even if exception happens in wrapper's model's __init__
-                best_model=grid_search_tmp.estimator.set_params(**grid_search_tmp.best_params_).fit(X, y),
+                best_model=grid_search_tmp.estimator.set_params(**best_param_rank["params"]).fit(X, y),
+                best_model_rank=best_param_rank["rank"],
                 cv_results=pd.DataFrame(grid_search_tmp.cv_results_),
                 cv_data=grid_search_tmp.scorer_.cv_data,
                 model_reprs=grid_search_tmp.scorer_.estimator_ids,
@@ -153,7 +199,10 @@ def _define_model_selection_flow():
     prefect.Flow
     """
 
-    from prefect import task, Flow, Parameter, unmapped
+    from prefect import Flow
+    from prefect import Parameter
+    from prefect import task
+    from prefect import unmapped
 
     with Flow("model selection") as flow:
         df = Parameter("data")
@@ -300,7 +349,7 @@ def run_model_selection(
     visualize_success : bool
         If True, generate graph of task completion
 
-    executor : prefect.engine.executors
+    executor : prefect.executors
         Provide prefect's executor.
         For more information see https://docs.prefect.io/api/latest/engine/executors.html
 
@@ -385,7 +434,7 @@ def select_model_general(
     parallel_over_columns : list, tuple
         Subset of partition_columns, that are used to parallel split.
 
-    executor : prefect.engine.executors
+    executor : prefect.executors
         Provide prefect's executor. Only valid when `parallel_over_columns` is set.
         For more information see https://docs.prefect.io/api/latest/engine/executors.html
 
