@@ -1,11 +1,13 @@
 import functools
+
 import pandas as pd
 
 from hcrystalball.utils import generate_estimator_hash
 from hcrystalball.utils import generate_partition_hash
 from hcrystalball.utils import get_estimator_name
-from .utils import _persist_to_file
+
 from .utils import _load_file
+from .utils import _persist_to_file
 
 load_model_selector_result = functools.partial(_load_file, expert_type="model_selector_result")
 
@@ -65,6 +67,7 @@ class ModelSelectorResult:
         frequency,
         horizon,
         country_code_column,
+        best_model_rank,
     ):
         self.best_model = best_model
         self.cv_results = cv_results
@@ -76,13 +79,16 @@ class ModelSelectorResult:
         self.frequency = frequency
         self.horizon = horizon
         self.country_code_column = country_code_column
+        self.best_model_rank = best_model_rank
 
         self.best_model_hash = generate_estimator_hash(best_model)
         self.best_model_cv_data = self.cv_data.rename({self.best_model_hash: "best_model"}, axis=1)[
             ["split", "y_true", "best_model"]
         ]
         self.best_model_name = get_estimator_name(best_model).replace("model__", "")
-        self.best_model_cv_results = self.cv_results[self.cv_results["rank_test_score"] == 1].iloc[0]
+        self.best_model_cv_results = self.cv_results[
+            self.cv_results["rank_test_score"] == self.best_model_rank
+        ].iloc[0]
         self.best_model_repr = self.model_reprs[self.best_model_hash]
         self.partition_hash = generate_partition_hash(self.partition)
 
@@ -219,7 +225,7 @@ class ModelSelectorResult:
                 )
                 if not plt_cv.empty:
                     plt.fill_between(
-                        x=plt_cv.index,
+                        x=plt_cv.index.values,
                         y1=max_y,
                         y2=min_y,
                         alpha=[0.2, 0.4][split % 2],
@@ -240,7 +246,7 @@ class ModelSelectorResult:
                 tmp_df = df[plot_from:].loc[lambda x: x["cv_split"] == split, ["cv_split_str"]]
                 if not tmp_df.empty:
                     plt.fill_between(
-                        x=tmp_df.index,
+                        x=tmp_df.index.values,
                         y1=max_y,
                         y2=min_y,
                         alpha=[0.2, 0.4][split % 2],
