@@ -1,7 +1,8 @@
 import pytest
+
+from hcrystalball.model_selection import ModelSelectorResult
 from hcrystalball.model_selection import run_model_selection
 from hcrystalball.model_selection import select_model_general
-from hcrystalball.model_selection import ModelSelectorResult
 
 
 @pytest.mark.parametrize(
@@ -10,9 +11,9 @@ from hcrystalball.model_selection import ModelSelectorResult
     indirect=["train_data", "grid_search"],
 )
 def test_prefect_executors(train_data, grid_search, parallel_columns):
-    from prefect.engine.executors import DaskExecutor
-    from prefect.engine.executors import LocalDaskExecutor
-    from prefect.engine.executors import LocalExecutor
+    from prefect.executors import DaskExecutor
+    from prefect.executors import LocalDaskExecutor
+    from prefect.executors import LocalExecutor
     from dask.distributed import Client
 
     client = Client()
