@@ -1,7 +1,7 @@
-import pytest
 import pandas as pd
+import pytest
 from pandas.testing import assert_frame_equal
-from fbprophet import Prophet
+from prophet import Prophet
 from hcrystalball.wrappers import ProphetWrapper
 
 
